@@ -22,6 +22,7 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 
 #include "dominion.h"
 #include "misc.h"
@@ -225,28 +226,28 @@ void delete_army_nation(Snation *np, Sarmy *ap)
     np->n_armies = 0;
     return;			/* blah, nothing to delete */
   }
-    /* see if the army to be deleted is the head of the list */
+  /* see if the army to be deleted is the head of the list */
   if ((alist->owner == ap->owner) && (alist->id == ap->id)) {
-      /* in this special case, copy the second army to
-	 the first, then free up the second. */
-    tmp = alist->next;		/* the next one must be saved for freeing */
+      /* in this special case (head of list), we can assign the
+         np->armies pointer to be the second in the list, and free up
+         the head of the list */
     if (alist->next != NULL) {
-      *alist = *(alist->next);
-      free(tmp);
+      np->armies = np->armies->next;
+      free(alist);              /* alist was still the head of the list */
     } else {
-      np->armies = NULL;
+      np->armies = NULL;        /* in this case we have no armies left */
       free(alist);
     }
     np->n_armies--;
     return;
   }
-    /* get hold of the army id we are looking for */
+  /* get hold of the army id we are looking for */
   while ( (tmp != NULL) &&
 	 !( (tmp->owner == ap->owner) && (tmp->id == ap->id) ) ) {
     prev = tmp;			/* remember the previous element */
     tmp = tmp->next;
   }
-    /* now we have the same army, so we can remove it */
+  /* now we have the same army, so we can remove it */
   if (tmp == NULL) {
     return;			/* blah, we didn't find it */
   }
