@@ -21,13 +21,15 @@
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <stdio.h>
+#include <math.h>
+#include <string.h>
+#include <unistd.h>
+
 #include "dominion.h"
 #include "misc.h"
 #include "army.h"
 
-#include <stdio.h>
-#include <math.h>
-
 struct army_info {
   struct armyid *armyid;	/* pointer to army in sector list */
   int size;			/* actual size of the army */
@@ -74,18 +76,18 @@ void dobattles()
   char tmp_name[100];
   char subj[100];
   int had_battles = 0;
+  int fd;
 
   dm = allocate_diplo(world.n_nations);
   read_in_diplo(dm,world.n_nations);
 
   /* a temporary file name for this news posting */
   strcpy(tmp_name, "dominionXXXXXX");
-  mktemp(tmp_name);
-
-  if (strlen(tmp_name) == 0) {
+  if ((fd = mkstemp(tmp_name)) == -1) {
     fprintf(stderr, "Error getting temp file name\n");
     return;
   }
+  close(fd);
   if ((news_fp = fopen(tmp_name, "w")) == NULL) {
     fprintf(stderr, "Error opening file %s for writing\n", tmp_name);
     return;
