@@ -23,6 +23,7 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <unistd.h>
+#include <string.h>
 
 #include "dominion.h"
 #include "news.h"
@@ -657,17 +658,18 @@ void news()
     clear();
     g_temp=news_groups_menu(1,0); /* 1=human, 0=posting(!reading) */
     clear();
-    if(g_temp!=NULL)
-      {
-	strcpy(tmp_fname, "/usr/tmp/domXXXXXX");
-	if (mktemp(tmp_fname) == NULL) {
-	  fprintf(stderr,"Error getting temp file name\n");
-	  fflush(stderr);
-	  return;
-	}
-	statline("Enter Subject","Posting News");
-	mvaddstr(2,1,"Subject: ");
-	wget_name(stdscr, subj);
+    if(g_temp!=NULL) {
+      int fd;
+      strcpy(tmp_fname, "/usr/tmp/domXXXXXX");
+      if ((fd = mkstemp(tmp_fname)) == -1) {
+        fprintf(stderr,"Error getting temp file name\n");
+        fflush(stderr);
+        return;
+      }
+      close(fd);
+      statline("Enter Subject","Posting News");
+      mvaddstr(2,1,"Subject: ");
+      wget_name(stdscr, subj);
 /*	echo();
 	nocbreak();
 	refresh();
@@ -676,13 +678,13 @@ void news()
 	cbreak();
 	refresh();
 */
-	cleanup();
-	chdir("/usr/tmp");
-	edit(tmp_fname);
-	chdir(current_dir);
-	chdir(libdir);
-	{
-	  refresh();
+      cleanup();
+      chdir("/usr/tmp");
+      edit(tmp_fname);
+      chdir(current_dir);
+      chdir(libdir);
+      {
+        refresh();
 /*	  init_screen(); */
 /*	  initscr();
 	  savetty();
@@ -691,40 +693,39 @@ void news()
 	  noecho();
 	  clear();
 */
-	}
-	mvaddstr(2,0,"Choices: S)end news or A)bort posting ");
-	refresh();
-	not_done=1;
-	while(not_done) {
-	    switch(to_getch()) {
-	    case 'S':
-	    case 's':
-	      mvaddstr(3,9,"Posting News...");
-	      refresh();
-	      post_news_file(tmp_fname, g_temp->name, subj, user.id);
-	      mvaddstr(3,24,"done.");
-	      refresh();
-	      not_done=0;
-	      unlink(tmp_fname);
-	      break;
-	    case 'A':
-	      mvaddstr(3,23,"OK. Aborting...");
-	      refresh();
-	      unlink(tmp_fname);
-	      not_done=0;
-	      break;
-	    } /* switch */
-	  } /* while */
-	{
+      }
+      mvaddstr(2,0,"Choices: S)end news or A)bort posting ");
+      refresh();
+      not_done=1;
+      while(not_done) {
+        switch(to_getch()) {
+        case 'S':
+        case 's':
+          mvaddstr(3,9,"Posting News...");
+          refresh();
+          post_news_file(tmp_fname, g_temp->name, subj, user.id);
+          mvaddstr(3,24,"done.");
+          refresh();
+          not_done=0;
+          unlink(tmp_fname);
+          break;
+        case 'A':
+          mvaddstr(3,23,"OK. Aborting...");
+          refresh();
+          unlink(tmp_fname);
+          not_done=0;
+          break;
+        } /* switch */
+      } /* while */
+      {
 /*	  cleanup(); */
-
-	  erase();
-	  touchwin(stdscr);
-	  refresh();
-
+        erase();
+        touchwin(stdscr);
+        refresh();
+        
 /*	  init_screen(); */
-	}
-      } /* if g_temp!=NULL */
+      }
+    } /* if g_temp!=NULL */
     break;
   } /* switch */
   user.just_moved = 1;
