@@ -20,15 +20,17 @@
  * along with this software; see the file COPYING.  If not, write to
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#include "config.h"
-#include "dominion.h"
-#include "misc.h"
-#include "army.h"
 #include <math.h>
 #include <curses.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <signal.h>
+#include <string.h>
+
+#include "config.h"
+#include "dominion.h"
+#include "misc.h"
+#include "army.h"
 
 /* some prototypes used here */
 void init_cn(Snation *np);
@@ -442,7 +444,7 @@ void do_cn_summon(Snation *np)
     army.next = NULL;
     army.flags = this_stype.flags;
 
-  /*============ now insert it into the list ============*/
+    /***************** now insert it into the list *****************/
 
     ++np->n_armies;
     if (np->armies == NULL) { 		/* special case:  empty list */
@@ -532,7 +534,7 @@ void do_cn_merge(Snation *np)
       }		/* for y */
     }		/* for x */
 
-  /* now move the army to the correct location and merge.  */
+    /* now move the army to the correct location and merge.  */
     if (bestarmy && (bestarmy->id != ap->id)){
       if (debug >= 2) {
         printf("cn army %d merges with %d.\n",ap->id,bestarmy->id);
@@ -546,7 +548,7 @@ void do_cn_merge(Snation *np)
       args[1].data.num = ap->id;
       args[2].data.num = bestarmy->id;
       printf("%s -- 0x%08lx about to cmd_amerge\n", np->name, (unsigned long) ap);
-      printf("%s -- 0x%08lx  %d about to cmd_amerge\n", np->name, (unsigned long) ap, ap->id);
+      printf("%s -- 0x%08lx  %d about to cmd_amerge %d\n", np->name, (unsigned long) ap, ap->id, bestarmy->id);
       cmd_amerge(np,args);
     }
     printf("%s -- 0x%08lx end of ap loop\n", np->name, (unsigned long) ap);
