@@ -30,6 +30,7 @@
 # include <sys/types.h>
 #endif
 #include <sys/wait.h>
+#include <string.h>
 
 #include <time.h>
 #include <ctype.h>
@@ -92,7 +93,7 @@ void mail_read(int reader)
       system(mail_command);
 */
     strcpy(tmp_fname,"/usr/tmp/dom_XXXXXX");
-    mktemp(tmp_fname);
+    mkstemp(tmp_fname);
     sprintf(mail_command, "cp %s/mail.%d %s", MAIL_DIR, reader,tmp_fname);
     system(mail_command);
     sprintf(mail_command, "chmod 666 %s", tmp_fname);
