@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
+#include <string.h>
 
 #ifdef AMIGA
 # include <exec/types.h>
@@ -230,6 +231,7 @@ int mail_send(char mailfile[], int sender, int receiver, char subject[])
   char dest_fn[200], *now_chars;
   FILE *dest_fp;
   char *forward, fixed_name[NAMELEN], fixed_name2[NAMELEN];
+  int fd;
 
   if ((forward = world.nations[receiver].opts->mail_forward)) {
     FILE *temp_fp;
@@ -240,7 +242,11 @@ int mail_send(char mailfile[], int sender, int receiver, char subject[])
 #endif
 
       strcpy(tmp_fname, "/usr/tmp/domXXXXXX");
-      mktemp(tmp_fname);
+      if ((fd = mkstemp(tmp_fname)) == -1) {
+        fprintf(stderr, "Error getting temp file name\n");
+        return 1;
+      }
+      close(fd);
       temp_fp = fopen(tmp_fname, "w");
       if (!temp_fp) {
 	perror("Could not open temp file");
