@@ -21,14 +21,16 @@
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "dominion.h"
-#include "misc.h"
-#include "army.h"
 #include <stdio.h>
 /* #include <signal.h> */
 #include <math.h>
 #include <stdlib.h>
 #include <unistd.h>
+#include <string.h>
+
+#include "dominion.h"
+#include "misc.h"
+#include "army.h"
 
 void dom_print_intro();
 void get_user();
@@ -370,19 +372,19 @@ void get_map_info(int *x, int *y, int *size, int *type1, int *type2)
   *size = 30;
   fprintf(stderr, "\nCenter the map around what sector?\n");
   fprintf(stderr, "       x coordinate [0]: ");
-  gets(buff);
+  fgets(buff, NAMELEN-1, stdin);
   if (strlen(buff)) {
     sscanf(buff, "%d", &temp);
     *x = temp;
   }
   fprintf(stderr, "       y coordinate [0]: ");
-  gets(buff);
+  fgets(buff, NAMELEN-1, stdin);
   if (strlen(buff)) {
     sscanf(buff, "%d", &temp);
     *y = temp;
   }
   fprintf(stderr, "\nHow many sectors across the map [30]: ");
-  gets(buff);
+  fgets(buff, NAMELEN-1, stdin);
   if (strlen(buff)) {
     sscanf(buff, "%d", &temp);
     if ( (float)(temp) / 2.0 != (float)(temp / 2) ) /* even number */
@@ -403,7 +405,7 @@ void get_display_type(int *t1, int *t2)
   fprintf(stderr, "B: Both above and below water displayed");
   fprintf(stderr, "\nSelect sector shading from above list [None]: ");
 
-  gets(buff);
+  fgets(buff, NAMELEN-1, stdin);
   a = buff[0];
 
   switch (a) {
@@ -442,7 +444,7 @@ void get_display_type(int *t1, int *t2)
   fprintf(stderr, "\nn: Nation Mark\t d: Designation\t N: None\n");
   fprintf(stderr, "\nSelect sector text from above list [designation]: ");
 
-  gets(buff);
+  fgets(buff, NAMELEN-1, stdin);
   a = buff[0];
 
   switch (a) {
