@@ -21,10 +21,6 @@
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "dominion.h"
-#include "misc.h"
-#include "army.h"
-
 #include <stdio.h>
 #include <signal.h>
 #include <math.h>
@@ -32,6 +28,11 @@
 #include <time.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <string.h>
+
+#include "dominion.h"
+#include "misc.h"
+#include "army.h"
 
 extern Sworld world;
 extern Suser user;
@@ -1100,16 +1101,16 @@ void post_statistics()
   FILE *tmp_fp, *fopen();
   char tmp_name[PATHLEN];
   char subj[100];
+  int fd;
 
   /* a temporary file name for this news posting */
 /*  tmp_name = tmpnam(NULL, "dominion"); */
   strcpy(tmp_name, "dominionXXXXXX");
-  mktemp(tmp_name);
-
-  if (strlen(tmp_name) == 0) {
+  if ((fd = mkstemp(tmp_name)) == -1) {
     fprintf(stderr, "Error getting temp file name\n");
     return;
   }
+  close(fd);
   if ((tmp_fp = fopen(tmp_name, "w")) == NULL) {
     fprintf(stderr, "Error opening file %s for writing\n", tmp_name);
     return;
